from .global_config import (
    # Main functions
    configure_logging,
    set_log_to_console,
    # Configuration flags
    LOG_TO_CONSOLE,
    LOG_LEVEL,
    # Log levels for use in other modules
    DEBUG,
    INFO,
    WARNING,
    ERROR,
    CRITICAL,
)
